@@ -23,16 +23,18 @@ using namespace Kontact;
 #include <KCrash>
 #include <KLocalizedString>
 #include <KPluginMetaData>
-#include <KWindowSystem>
 
 #include <QCommandLineParser>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QPointer>
+#include <QWindow>
 
 #include <iostream>
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
 #endif
+
 using namespace std;
 
 static const char version[] = KONTACT_VERSION;
@@ -122,7 +124,7 @@ int KontactApp::activate(const QStringList &args, const QString &workingDir)
             // --iconify is needed in kontact, although kstart can do that too,
             // because kstart returns immediately so it's too early to talk D-Bus to the app.
             if (parser.isSet(QStringLiteral("iconify"))) {
-                KWindowSystem::minimizeWindow(mMainWindow->winId());
+                mMainWindow->windowHandle()->showMinimized();
             }
         } else {
             if (!moduleName.isEmpty()) {
@@ -162,7 +164,7 @@ int main(int argc, char **argv)
                      QLatin1String(version),
                      i18n("KDE personal information manager"),
                      KAboutLicense::GPL,
-                     i18n("Copyright © 2001–%1 Kontact authors", QStringLiteral("2022")),
+                     i18n("Copyright © 2001–%1 Kontact authors", QStringLiteral("2023")),
                      QString(),
                      QStringLiteral("https://userbase.kde.org/Kontact"));
 
